@@ -31,11 +31,10 @@ getNodeID.MPInode <- function(node) {
 }
 
 do.administration.MPIcluster <- function(cl, clall, d, p, it, n, manage, mngtfiles, 
-									x, frep, freenodes, initfun, 
-									gentype, seed, ft_verbose, ...) {
+									x, frep, freenodes, ...) {
 	free.nodes <- FALSE
 	updated.values <- manage.replications.and.cluster.size(cl, clall, p, n, manage, mngtfiles, 
-									freenodes, initfun, gentype, seed, ft_verbose=ft_verbose)
+									freenodes, ...)
 	if ((length(updated.values$freenodes) > 0) && (it <= n)) free.nodes <- TRUE
 
 	return(c(updated.values, list(frep=frep, d=d, is.free.node=free.nodes)))
